@@ -81,6 +81,9 @@ class ApiSettings(ApiBase):
     def add_bitbucket_repository(self):
         return self.build_route("settings/repositories/bitbucket")
 
+    def add_gitlab_repository(self):
+        return self.build_route("settings/repositories/gitlab")
+
     def repositories(self):
         return self.build_route("settings/repositories")
 
