@@ -13,7 +13,8 @@ from common.test_utils import TestUtils
 from gateways.apis.api_route_base import ApiRoot
 from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
     AddBlueprintUsingTokenRepositoryRequest, AddBlueprintGithubRepositoryRequest, \
-    AddBlueprintBitbucketRepositoryRequest, BitbucketBlueprintRepositoryDetails, TerraformModuleDescriptor
+    AddBlueprintBitbucketRepositoryRequest, BitbucketBlueprintRepositoryDetails, AddBlueprintGitlabRepositoryRequest, \
+    GitlabBlueprintRepositoryDetails, TerraformModuleDescriptor
 from gateways.common.cs18_api_converters import Converters
 from gateways.common.cs18_api_errors import UnauthorizedException, SandboxNotFound, \
     SandboxEndingFailed
@@ -764,6 +765,11 @@ class Colony:
         resp = self.session.post(url=method_url, json=request.__dict__)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    def add_account_blueprint_gitlab_repository(self, request: AddBlueprintGitlabRepositoryRequest):
+        method_url = self._api_root.settings.add_gitlab_repository()
+        resp = self.session.post(url=method_url, json=request.__dict__)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
     def delete_account_blueprint_repository(self, name: str):
         method_url = self._api_root.settings.repository(name)
         resp = self.session.delete(url=method_url)
@@ -852,6 +858,34 @@ class Colony:
                 subject="blueprints ready",
             )
 
+    def add_gitlab_repository_to_space_via_token(
+            self,
+            gitlab_blueprint_repository_details: GitlabBlueprintRepositoryDetails,
+            deployment_type: str = None,
+            wait_for_cache_refresh: bool = False,
+    ):
+
+        method_url = self._api_root.spaces.space_repositories(space_name=self.space, repository_type="gitlab")
+        request = {
+            "repository_url": gitlab_blueprint_repository_details.blueprint_repository_details.repository_url,
+            "code": gitlab_blueprint_repository_details.auth_code,
+            "repository_type": gitlab_blueprint_repository_details.blueprint_repository_details.repository_type,
+            "branch": gitlab_blueprint_repository_details.blueprint_repository_details.branch,
+            "type": deployment_type,
+            "redirection_url": gitlab_blueprint_repository_details.redirect_url
+        }
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+        if wait_for_cache_refresh:
+            Utils.wait_for(
+                func=lambda: (self.list_blueprints(exclude_samples=True) is not False),
+                interval_sec=5,
+                max_retries=24,
+                subject="blueprints ready",
+            )
+
     def remove_repository_from_space(self, wait_for_cache_refresh=False, space_name: str = None,
                                      deployment_type: str = None):
         if space_name is None:
@@ -1235,8 +1269,7 @@ class Colony:
                                   sso_update_enabled: bool):
         set_account_extra_details_url = self._api_root.account.set_account_extra_details(account_name)
         self.put_request(set_account_extra_details_url, {"sso_enabled": sso_enabled, "anonymous_users": anonymous_users,
-                                                         "sso_update_enabled": sso_update_enabled}
-                         , return_codes=[200])
+                                                         "sso_update_enabled": sso_update_enabled}, return_codes=[200])
 
     def get_account_extra_details(self, account_name: str) -> AccountExtraDetails:
         get_account_extra_details_url = self._api_root.account.get_account_extra_details(account_name)
@@ -1439,6 +1472,10 @@ class Colony:
             connection_details = {
                 "refresh_token": repository_details.access_token
             }
+        elif repository_details.repository_type == TestUtils.GITLAB_REPOSITORY_TYPE:
+            connection_details = {
+                "token": repository_details.access_token
+            }
 
         request = {
             "provider_id": repository_provider_id,
