@@ -60,6 +60,13 @@ class BitbucketBlueprintRepositoryDetails:
         self.redirect_url = redirect_url
 
 
+class GitlabBlueprintRepositoryDetails:
+    def __init__(self, auth_code: str, redirect_url: str, blueprint_repository_details: BlueprintRepositoryDetails):
+        self.blueprint_repository_details = blueprint_repository_details
+        self.auth_code = auth_code
+        self.redirect_url = redirect_url
+
+
 class AddAccountBlueprintRepositoryRequest(abc.ABC):
     def __init__(self, name: str, repository_url: str, allow_sharing: bool,
                  open_access: bool):
@@ -93,6 +100,14 @@ class AddBlueprintBitbucketRepositoryRequest(AddAccountBlueprintRepositoryReques
         self.redirection_url = redirection_url
 
 
+class AddBlueprintGitlabRepositoryRequest(AddAccountBlueprintRepositoryRequest):
+    def __init__(self, name: str, repository_url: str, allow_sharing: bool,
+                 open_access: bool, code: str, redirection_url: str):
+        super().__init__(name, repository_url, allow_sharing, open_access)
+        self.code = code
+        self.redirection_url = redirection_url
+
+
 class TerraformModuleInput(abc.ABC):
     def __init__(self, name: str, value: str,
                  optional: bool,
