@@ -535,8 +535,8 @@ class Converters:
         return SandboxOwnerResponse(
             first_name=user["first_name"],
             last_name=user["last_name"],
-            display_first_name=user["display_first_name"],
-            display_last_name=user["display_last_name"],
+            display_first_name=user.get("display_first_name"),
+            display_last_name=user.get("display_last_name"),
             email=user["email"],
             join_date=user["join_date"],
         )
